%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%This is part of the set of files that accompany the article:       %
%                                                                   %
%Ricardo Reis (2008) "Estimating a SIGE model for policy evaluation"%
%in Monetary Policy under Uncertainty, Central Bank of Chile.       %
%                                                                   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%STEP 1: LOADING DATA AND MANIPULATING IT%%%%%
clear; clc; clear global;
load USGdata.mat; global T K; [T K]=size(data); %load data
% Data matrix is Txk, where T is the number of observations and K is the
%number of variables in the model. First column is Dp, second is Dy, third
%is i, fourth is Dwp, fifth is l. All already de-meaned and i/4.
global Y; Y=data(1,1:K)'; for i=2:T; Y=[Y;data(i,1:K)']; end;
% Y matrix is 5*Tx1 and has the observations stacked
global N; N=100;     %periods in MA representations, must be larger than T

%%%%STEP 2: PARAMETER INPUTS - CALIBRATED PARAMETERS %%%%%%%
beta = 2/3;       %variable labor share
theta = 1;        %elasticity of intertemporal substitution
Da = data(2:T,2) - beta*(data(2:T,5)-data(1:T-1,5));
[rho_a,temp1,temp2,temp3,temp4] = regress(Da(2:T-1,1),Da(1:T-2,1));
sigma_a = sqrt(temp4(4)); %rho_a and sigma_a
clear Da temp1 temp2 temp3 temp4
global pars_c;
pars_c=[beta NaN theta NaN NaN NaN NaN NaN NaN rho_a sigma_a NaN];
pars_c=[pars_c NaN NaN NaN NaN NaN NaN NaN NaN];
clear beta theta sigma_a rho_a

%%%%% STEP 3: BAYESIAN PRIORS %%%%%
global Ppar; load Prior_pars.mat Ppar;

%%%%% STEP 4: SIMULATION PARAMETERS %%%%%
%Mode of posterior used for proposal function (with the Hessian)
load SIGE_USGmode x0 VARCOV; global cc
%Previous draws for proposal function used as proposal with updated var-cov
%load BayesdrawUSGvc mea vc; x0=mea'; VARCOV=vc; clear mea vc; global cc;
M=200000; cc=0.5;
draw=x0;
%draw=mvnrnd(x0,9*(cc^2)*VARCOV)'; while SIGEpost(draw)>0; draw=mvnrnd(x0,9*(cc^2)*VARCOV)'; end
logd=SIGEloglik(draw); prior=SIGEprior(draw); %starting values


%%%%% STEP 5: DRAWING PARAMETERS FROM POSTERIOR %%%%%
draws=draw; accepts=1; logds=logd; %Storage of results
%Iterating over the Gibbs sampler steps
tic
h = waitbar(0,'Going over Metropolis jumps iterations one MCMC chain...');
taper=1; %ow many draws want to save. If set=1 better to delete to save the
         %time-consuming if step below.
for i=1:M
    [draw accept logd prior]=SIGEmetro(draw,VARCOV,logd,prior);
    if (floor(i/taper)-i/taper)==0;
        draws=[draws,draw]; logds=[logds;logd]; accepts=[accepts; accept];
        waitbar(i/M,h);
    end
    if (floor(i/20000)-i/20000)==0; save BayesdrawUSG11.mat; end
end
close(h); clear h accept; toc; 
save BayesdrawUSG01.mat   %CHANGE THIS TO NOT OVERWRITE OLD RESULTS

%%%%% STEP 4: ANALYSE DRAWS %%%%%%
disp('rate_of_acceptance'); disp(mean(accepts(M/2+1:M,:)))