function [draw accept log_density prior] = SIGEmetro(x0,VARCOV,logd_x0,prior_x0)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%This is part of the set of files that accompany the article:       %
%                                                                   %
%Ricardo Reis (2008) "Estimating a SIGE model for policy evaluation"%
%in Monetary Policy under Uncertainty, Central Bank of Chile.       %
%                                                                   %
%See the appendix of the paper or its NBER or CEPR working paper    %
%versions for a detailed explanation of the algorithms.             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Please cite if you use the programs. I do not provide tech support.%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%This file: Metropolis iteration, almost exact copy of Mankiw-Reis  %
%  programs, just adjusted for new loglik and prior programs        %
%Last revised: October 30, 2007                                     %
%Written by: Tiago Berriel and Ricardo Reis                         %
%Input: the proposal mean and variance, the likelihood and prior den%
%Output: the draw, whether to accept, the likelihood and prior densi%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

global T K N Y pars_c cc

%%%%% STEP 1: NEW DRAW %%%%%%
candidate = mvnrnd(x0,(cc^2)*VARCOV);
prior_candidate = SIGEprior(candidate);

%%%%% STEP 2: METROPOLIS ACCEPTANCE %%%%%%
draw=x0; accept=0; prior=prior_x0; log_density=logd_x0; %baseline is reject
if prior_candidate~=0
    ldc = SIGEloglik(candidate);   %this is the numerically costly step
    r = exp(-ldc+logd_x0)*(prior_candidate/prior_x0);
    U=rand;
    if U<r;
        draw=candidate'; accept=1; log_density=ldc; prior=prior_candidate;
        disp('Metropolis jump to posterior density:'); disp(-ldc+log(prior));
    end %only accept here
end
