function prior = SIGEprior(pars_e)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%This is part of the set of files that accompany the article:       %
%                                                                   %
%Ricardo Reis (2008) "Estimating a SIGE model for policy evaluation"%
%in Monetary Policy under Uncertainty, Central Bank of Chile.       %
%                                                                   %
%See the appendix of the paper or its NBER or CEPR working paper    %
%versions for a detailed explanation of the algorithms.             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Please cite if you use the programs. I do not provide tech support.%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%This file: compute prior density, copy of SIGEprior in Mankiw Reis %
%  (2007, JEEA) changed to include also policy parameters           %
%Last revised: October 30, 2007                                     %
%Written by: Tiago Berriel and Ricardo Reis                         %
%Input: the 15 parameters being estimated                           %
%Output: the prior density                                          %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

global Ppar

prior=1;
%Probability of coming from prior for all 15 parameters
prior=prior*gampdf(pars_e(1)-1,Ppar(1,1),Ppar(2,1));   %nu
prior=prior*gampdf(pars_e(2)-1,Ppar(1,2),Ppar(2,2));   %gamma
prior=prior*gampdf(pars_e(3),Ppar(1,3),Ppar(2,3));     %phiy
prior=prior*gampdf(pars_e(4)-1,Ppar(1,4),Ppar(2,4));   %phipi

prior=prior*betapdf(pars_e(5),Ppar(1,5),Ppar(2,5));         %rho_m
prior=prior*betapdf(pars_e(7),Ppar(1,7),Ppar(2,7));         %rho_g     
prior=prior*betapdf(pars_e(9),Ppar(1,9),Ppar(2,9));         %rho_nu
prior=prior*betapdf(pars_e(11),Ppar(1,11),Ppar(2,11));      %rho_gam

prior=prior*gampdf(1/(pars_e(6)^2),Ppar(1,6),Ppar(2,6));    %sigma_m
if pars_e(6)<0; prior = 0; end          %ensure not negative
prior=prior*gampdf(1/(pars_e(8)^2),Ppar(1,8),Ppar(2,8));    %sigma_g
if pars_e(8)<0; prior = 0; end
prior=prior*gampdf(1/(pars_e(10)^2),Ppar(1,10),Ppar(2,10)); %sigma_nu
if pars_e(10)<0; prior = 0; end
prior=prior*gampdf(1/(pars_e(12)^2),Ppar(1,12),Ppar(2,12)); %sigma_gam
if pars_e(12)<0; prior = 0; end

prior=prior*gampdf(pars_e(16),Ppar(1,16),Ppar(2,16));     %psi NEW

if pars_e(13)>1; prior = 0; end  %delta
if pars_e(14)>1; prior = 0; end  %omega
if pars_e(15)>1; prior = 0; end  %lambda
if pars_e(13)<0; prior = 0; end  %delta
if pars_e(14)<0; prior = 0; end  %omega
if pars_e(15)<0; prior = 0; end  %lambda
